# variables

$path = Split-Path $Global:MyInvocation.InvocationName

$url = Join-Path $path "LaserProducts.zip"
$appIcon = Join-Path $path "app.ico"
$latesturl = Join-Path $path "lp_1.0.0.289_update.zip"
$falconTempDir = Join-Path $env:ProgramFiles "Falcon"
$falconDir = Join-Path $falconTempDir "falconInstall"
if (![System.IO.Directory]::Exists($falconDir)) {[System.IO.Directory]::CreateDirectory($falconDir)}
$file = Join-Path $falconDir "LaserProducts.zip"
$updateFile = Join-Path $falconDir "Update.zip"
$iconFile = Join-Path $falconTempDir "app.ico"
$launcherPath = Join-Path $env:ProgramFiles "falcon\\Falcon.Launcher.exe"
$iconPath = Join-Path $env:ProgramFiles "falcon\\Falcon.LaserProducts.Windows.exe"

function Download-File {
param (
  [string]$url,
  [string]$file
 )
  Write-Host "Downloading $url to $file"
  $downloader = new-object System.Net.WebClient
  $downloader.DownloadFile($url, $file)
}

# download the package
Copy-Item $url $file
Copy-Item $latesturl $updateFile
Copy-Item $appIcon $iconFile

# download 7zip
Write-Host "Download 7Zip commandline tool"
$7zaExe = Join-Path $falconDir '7za.exe'
$7zPath = Join-Path $path '7za.exe' 

Copy-Item $7zPath "$7zaExe"

# unzip the package
Write-Host "Extracting $file to $falconTempDir..."
Start-Process "$7zaExe" -ArgumentList "x -o`"$falconTempDir`" -y `"$file`"" -Wait
Start-Process "$7zaExe" -ArgumentList "x -o`"$falconTempDir`" -y `"$updateFile`"" -Wait

get-childitem $falconTempDir -include * -recurse | Set-ItemProperty -name IsReadOnly -value $false -ErrorAction SilentlyContinue

#Get the ACL
$acl = Get-Acl -Path $falconTempDir
#List Users/Groups in ACL with permissions
$acl.Access | Select IdentityReference, FileSystemRights
#Remove All non-inherited Permissions
$acl.Access | ForEach-Object {if ($_.IsInherited -eq $False) {$acl.RemoveAccessRule($_)}}
#Add ACE to grant Group ReadAndExecute for "This Folder, Subfolders and Files"
$rule = New-Object System.Security.AccessControl.FileSystemAccessRule("everyone","FullControl", "ContainerInherit, ObjectInherit", "None", "Allow")
$acl.AddAccessRule($rule)
#Set the modified ACL
Set-Acl -Path $falconTempDir -AclObject $acl 

$WshShell = New-Object -comObject WScript.Shell
$Shortcut = $WshShell.CreateShortcut("$Home\Desktop\TemplatePro.lnk")
$Shortcut.TargetPath = $launcherPath
$Shortcut.IconLocation = $iconFile
$Shortcut.Save()